==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/modeewert.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS modeewert//
create function modeewert(wid integer, anz integer, mode varchar(12),
                          neh varchar(100)) returns varchar(50)
  deterministic
  sql security invoker
  begin
    declare wlen, f, counter, z integer;
    declare w, wmin, wmax, wlast varbinary(20);
    declare wsum2, wsum double;
    declare lastdate, d datetime(6);
    declare selcur cursor for select ehwconv(wert, neh), length(wert), datum from twerte
      where werteindizesID = wid order by datum desc;
    declare continue handler for not found set z = 1;

    set counter = 0;
    set z = 0;
    if mode = 'size' then
      set anz = 1;
      set mode = 'firstsize';
    elseif mode = 'last' then
      set anz = 1;
      set mode = 'first';
    end if;
    open selcur;
    repeat
      fetch selcur into w, wlen, d;
      if z != 1
       then
        if counter = 0 then
          set lastdate = d;
          set wmin = w;
          set wmax = w;
          set wsum = w;
          set wsum2 = w*w;
          set wlast = w;
          set f = length(0+replace(w, '.',''));
        elseif counter = 1 && mode like 'last/avg%' then
          set wsum = w;
          set anz = anz + 1;
        else
          set wsum = wsum + w;
          set wsum2 = wsum2 + w*w;
          if length(0+replace(w, '.','')) > f then
            set f = length(0+replace(w, '.',''));
          end if;
          if 0+w < 0+wmin then
            set wmin = w;
          end if;
          if 0+w > 0+wmax then
            set wmax = w;
          end if;
        end if;
        set counter = counter + 1;
      end if;
      until (counter >= anz || z = 1)
    end repeat;
    close selcur;
    if counter >= anz && counter > 0
     then
      case mode
        when 'count' then
          return counter;
        when 'avg' then
          set wsum = wsum / counter;
          return round(wsum, f + 2 - locate('.', wsum));
        when 'dev' then
          if counter > 1 then
            set wsum = sqrt((wsum2 - wsum*wsum/counter)/(counter-1));
            return round(wsum, f + 2 - locate('.', wsum));
          else
            return '';
          end if;
        when 'last/avg' then
          if wsum != 0 then
            set wsum = wlast / wsum * (counter-1);
            return cast(round(wsum, f + 2 - locate('.', wsum)) as char(30));
          else
            return '';
          end if;
        when 'last/avg-1' then
          if wsum != 0 AND counter > 1 then
            set wsum = wlast / wsum * (counter-1) - 1;
            return cast(round(wsum, f + 2 - locate('.', wsum)) as char(30));
          else
            return '';
          end if;
        when 'sum' then
          return round(wsum, f + 1 - locate('.', wsum));
        when 'min' then
          return wmin;
        when 'max' then
          return wmax;
        when 'max-min' then
          set wsum = wmax - wmin;
          return round(wsum, f + 1 - locate('.', wsum));
        when 'last-first' then
          set wsum = wlast - w;
          return round(wsum, f + 1 - locate('.', wsum));
        when 'last-first+' then
          set wsum = wlast - w;
          if wsum >= 0 then
            return round(wsum, f + 1 - locate('.', wsum));
          else
            return '';
          end if;
        when 'last-first-' then
          set wsum = wlast - w;
          if wsum <= 0 then
            return round(wsum, f + 1 - locate('.', wsum));
          else
            return '';
          end if;
        when 'first' then
          return w;
        when 'differ' then
          return w != wlast;
        when 'firstsize' then
          return wlen;
        when 'grad' then
          return gradientevbextfilter(wid, d, lastdate, '00:00:00', '24:00:00', '',
                                      '', '', '', '', '', '', '', '', '', '', '', neh);
        when 'accel' then
          return accele(wid, d, lastdate, '00:00:00', '24:00:00', '',
                        '', '', '', '', '', '', '', '', '', '', '', neh);
        else
          return '';
      end case;
    else
      return '';
    end if;
  end//

GRANT EXECUTE on FUNCTION modeewert to logginglesen@'localhost', loggingtest@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/modeewert.sql <==
-- modeewert.sql
--
-- function modeewert(wid, anz, mode, neh) returns varchar
-- wid: werteindizesID
-- anz: number ob values
-- mode: aggregation mode
-- neh: output unit
-- return: aggregated value of the last "anz" values with werteindizesID == "wid" unit [E]

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS modeewert//
create function modeewert(wid integer, anz integer, mode varchar(12),
                          neh varchar(100)) returns varchar(50)
  deterministic
  sql security invoker
  begin
    declare wlen, f, counter, z integer;
    declare w, wmin, wmax, wlast varchar(20);
    declare wsum2, wsum double;
    declare lastdate, d datetime(6);
    declare selcur cursor for select ehwconv(wert, neh), length(wert), datum from twerte
      where werteindizesID = wid order by datum desc;
    declare continue handler for not found set z = 1;

    set counter = 0;
    set z = 0;
    if mode = 'size' then
      set anz = 1;
      set mode = 'firstsize';
    elseif mode = 'last' then
      set anz = 1;
      set mode = 'first';
    end if;
    open selcur;
    repeat
      fetch selcur into w, wlen, d;
      if z != 1
       then
        if counter = 0 then
          set lastdate = d;
          set wmin = w;
          set wmax = w;
          set wsum = w;
          set wsum2 = w*w;
          set wlast = w;
          set f = length(0+replace(w, '.',''));
        elseif counter = 1 && mode like 'last/avg%' then
          set wsum = w;
          set anz = anz + 1;
        else
          set wsum = wsum + w;
          set wsum2 = wsum2 + w*w;
          if length(0+replace(w, '.','')) > f then
            set f = length(0+replace(w, '.',''));
          end if;
          if 0+w < 0+wmin then
            set wmin = w;
          end if;
          if 0+w > 0+wmax then
            set wmax = w;
          end if;
        end if;
        set counter = counter + 1;
      end if;
      until (counter >= anz || z = 1)
    end repeat;
    close selcur;
    if counter >= anz && counter > 0
     then
      case mode
        when 'count' then
          return counter;
        when 'avg' then
          set wsum = wsum / counter;
          return round(wsum, f + 2 - locate('.', wsum));
        when 'dev' then
          if counter > 1 then
            set wsum = sqrt((wsum2 - wsum*wsum/counter)/(counter-1));
            return round(wsum, f + 2 - locate('.', wsum));
          else
            return '';
          end if;
        when 'last/avg' then
          if wsum != 0 then
            set wsum = wlast / wsum * (counter-1);
            return cast(round(wsum, f + 2 - locate('.', wsum)) as char(30));
          else
            return '';
          end if;
        when 'last/avg-1' then
          if wsum != 0 AND counter > 1 then
            set wsum = wlast / wsum * (counter-1) - 1;
            return cast(round(wsum, f + 2 - locate('.', wsum)) as char(30));
          else
            return '';
          end if;
        when 'sum' then
          return round(wsum, f + 1 - locate('.', wsum));
        when 'min' then
          return wmin;
        when 'max' then
          return wmax;
        when 'max-min' then
          set wsum = wmax - wmin;
          return round(wsum, f + 1 - locate('.', wsum));
        when 'last-first' then
          set wsum = wlast - w;
          return round(wsum, f + 1 - locate('.', wsum));
        when 'last-first+' then
          set wsum = wlast - w;
          if wsum >= 0 then
            return round(wsum, f + 1 - locate('.', wsum));
          else
            return '';
          end if;
        when 'last-first-' then
          set wsum = wlast - w;
          if wsum <= 0 then
            return round(wsum, f + 1 - locate('.', wsum));
          else
            return '';
          end if;
        when 'first' then
          return w;
        when 'differ' then
          return w != wlast;
        when 'firstsize' then
          return wlen;
        when 'grad' then
          return gradientevbextfilter(wid, d, lastdate, '00:00:00', '24:00:00', '',
                                      '', '', '', '', '', '', '', '', '', '', '', neh);
        when 'accel' then
          return accele(wid, d, lastdate, '00:00:00', '24:00:00', '',
                        '', '', '', '', '', '', '', '', '', '', '', neh);
        else
          return '';
      end case;
    else
      return '';
    end if;
  end//

GRANT EXECUTE on FUNCTION modeewert to logginglesen@'localhost', loggingtest@'localhost'//
